/* *********************************************************************
 * Class MetaDataProvider
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * For your convenience it is dual licensed.
 * You can redistribute it and/or modify it under the terms of
 * one of the following licenses:
 * 
 * 1.)
 * The GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl-3.0.txt); if not please read
 * http://www.gnu.org/licenses/gpl.html
 * 
 * 2.)
 * The European Union Public Licence as published by
 * The European Commission (executive body of the European Union);
 * either version 1.1 of the License, or (at your option) any later version.
 * You should have received a copy of the European Union Public Licence
 * along with this program (eupl_v1.1_en.pdf); if not please read
 * http://www.osor.eu/eupl
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the above licenses for more details.
 * 
 * Jürgen Kett, Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-04-03 Port to Maven by Timo Heck & Karaca Kocer
 * 2010-06-11 Code formatting and license text by Karaca Kocer
 * 2010-05-05 Refactoring + new package structure by Karaca Kocer
 * Created on 2010-03-17 by Jürgen Kett
 ********************************************************************/

package org.culturegraph.resolver.api;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import eu.europeanaconnect.erds.DataProvider;
import eu.europeanaconnect.erds.ResolverException;
import eu.europeanaconnect.erds.ResolverRequest;
import eu.europeanaconnect.erds.ResolverException.ResolverExceptionCode;

/**
 * Provides meta data for a given persistent identifier.
 * @author Jürgen Kett (Original code)
 * @author Kadir Karaca Kocer (Refactoring, license text, comments & JavaDoc)
 * @param <R> 
 */
public class MetaDataProvider<R> implements DataProvider<R> {
    private static final Log LOGGER = LogFactory.getLog(MetaDataProvider.class);
    private String id;
    private List<DataProvider<R>> dataProviders;

    /**
     * @return List of registered data providers. See the configuration in XML file.
     */
    public List<DataProvider<R>> getDataProviders() {
        return this.dataProviders;
    }

    /**
     * @param providers
     */
    public void setDataProviders(List<DataProvider<R>> providers) {
        this.dataProviders = providers;
    }

    /**
     * {@inheritDoc}
     */
    @Override
	public String getId() {
        return this.id;
    }

    /**
     * @param newId
     */
    public void setId(String newId) {
        this.id = newId;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public R getResponse(ResolverRequest request) throws ResolverException {
        R ret = null;
        ResolverException storedException = null;
        if (LOGGER.isDebugEnabled()) LOGGER.debug("Searching a matching MetadataProvider");
        // resolve identifier
        for (DataProvider<R> resolver : this.dataProviders) {
            if (request.getIdentifier().matches(resolver.getIdentifierPattern())) {
                try {
                	if (LOGGER.isDebugEnabled()) LOGGER.debug("Identifier pattern matched. Trying to get a response");
                    ret = resolver.getResponse(request);
                    break;
                } catch (ResolverException e) {
                    LOGGER.error("Resolver.getResponse caused an error: ", e);
                    storedException = e;
                }
            }
            if (storedException != null) {
                throw storedException;
            }
        }
        if (ret == null) {
            throw new ResolverException(this.id, ResolverExceptionCode.UNSUPPORTED_IDENTIFIER_SCHEME);
        }
        return ret;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getIdentifierPattern() {
        // nothing to do
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public List<String> getSupportedNamespaces() {
        // nothing to do
        return null;
    }
}