/* *********************************************************************
 * Class XmlResourceDescriptionHandler
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * For your convenience it is dual licensed.
 * You can redistribute it and/or modify it under the terms of
 * one of the following licenses:
 * 
 * 1.)
 * The GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl-3.0.txt); if not please read
 * http://www.gnu.org/licenses/gpl.html
 * 
 * 2.)
 * The European Union Public Licence as published by
 * The European Commission (executive body of the European Union);
 * either version 1.1 of the License, or (at your option) any later version.
 * You should have received a copy of the European Union Public Licence
 * along with this program (eupl_v1.1_en.pdf); if not please read
 * http://www.osor.eu/eupl
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the above licenses for more details.
 * 
 * Jürgen Kett, Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

/* ******************************************************************
 * CHANGELOG:
 * 
 * 2012-04-03 Port to Maven by Timo Heck & Karaca Kocer
 * 2010-06-09 Code formatting and license text by Karaca Kocer
 * 2010-05-05 Refactoring + new package structure by Karaca Kocer
 * Created on 2010-03-17 by Jürgen Kett
 ********************************************************************/

package org.culturegraph.resolver.api;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.util.List;

import javax.xml.namespace.QName;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;

import eu.europeanaconnect.erds.Property;
import eu.europeanaconnect.erds.ResourceDescription;

/**
 * 
 * @author Jürgen Kett (Original code)
 * @author Kadir Karaca Kocer (Refactoring, license text)
 */

public class XmlResourceDescriptionHandler implements ResourceDescriptionHandler {
    private static final Log LOGGER = LogFactory.getLog(XmlResourceDescriptionHandler.class);
    private QName recordRootElement;

    /**
     * @return Root element of the record.
     */
    public QName getRecordRootElement() {
        return this.recordRootElement;
    }

    /**
     * @param recordRootElement Root element to set.
     */
    public void setRecordRootElement(QName recordRootElement) {
        this.recordRootElement = recordRootElement;
    }

    /**
     * {@inheritDoc}
     */
    @Override
	public ResourceDescription parse(InputStream stream) throws XmlException, IOException {
        return analyseXmlObject(XmlObject.Factory.parse(stream));
    }

    /**
     * {@inheritDoc}
     */
    @Override
	public ResourceDescription parse(Reader reader) throws Exception {
        return analyseXmlObject(XmlObject.Factory.parse(reader));
    }

    /**
     * @param xmlObj
     * @return ResourceDescription
     * @throws XmlException
     * @throws IOException
     */
    public ResourceDescription analyseXmlObject(XmlObject xmlObj) throws XmlException, IOException {
        if (LOGGER.isDebugEnabled()) {LOGGER.debug("inputDoc: " + xmlObj.toString());}
        ResourceDescription ret = new ResourceDescription();
        XmlCursor cursor = xmlObj.newCursor();
        while (cursor.hasNextToken()) {
            cursor.toNextToken();
            if (this.recordRootElement.equals(cursor.getName())) {
                ret.setProperties(createProperties(cursor.getObject()));
                ret.setRawContent(cursor.xmlText(new XmlOptions().setSaveOuter()));
                break;
            }
        }
        return ret;
    }

    /**
     * @param xmlObject
     * @return List of Properties.
     * @throws XmlException
     */
    @SuppressWarnings("static-method")
    public List<Property<String, String>> createProperties(XmlObject xmlObject) throws XmlException {
        return null;
    }

}
