/* *********************************************************************
 * Class PidefDocumentGenerator
 * 
 * Copyright (c) 2011-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Thomas Haidlas -- German National Library
 * Kadir Karaca Kocer -- German National Library
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-04-03 Port to Maven by Timo Heck & Karaca Kocer
 * 2012-02-20 Status Code and Password are optional and will not be set --Karaca
 * 2011-12-12 Licence information and JavaDocs by Karaca Kocer
 * Created on 2011-12-08 by Thomas Haidlas -- German National Library
 ********************************************************************/

package org.nbnResolving.resolver;

//import javax.xml.namespace.QName;

//import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlOptions;
import org.nbnResolving.pidef.HeaderType;
import org.nbnResolving.pidef.PidefDocument;
import org.nbnResolving.pidef.PidefDocument.Pidef;

/**
 * @author Thomas Haidlas, German National Library
 *
 */
@SuppressWarnings("static-method")
public class PidefDocumentGenerator {
	// for Apache XmlBeans
	private static String  characterEncoding = "UTF-8";
	private static String  doctypeName = "DocType Name Not Set";
	private static boolean isStandalone = true;
	private static String  sourceName = "Source Name Not Set";
	private static String  version = "1.0";
	// for PIDEF
	private static String  request = "Request Not Set!";
	private static short   statusCode = -1;
	private static String  source = "URN:NBN System Of The German National Library";
	private static String  organisation ="Deutsche Nationalbibliothek / German National Library";
	private static boolean isPrettyPrint = true;
	
	/**
	 * @return The chacter encoding.
	 */
    public String getCharacterEncoding() {
		return characterEncoding;
	}
	
	/**
	 * @param newEncoding Character encoding to set.
	 */
	public void setCharacterEncoding(String newEncoding) {
		characterEncoding = newEncoding;
	}
	
	/**
	 * @return The DocTypeName
	 */
	public String getDoctypeName() {
		return doctypeName;
	}
	
	/**
	 * @param newDoctypeName DocTypeName to set.
	 */
	public void setDoctypeName(String newDoctypeName) {
		doctypeName = newDoctypeName;
	}
	
	/**
	 * @return Apache XML Beans property
	 */
	public boolean isStandalone() {
		return isStandalone;
	}	
	
	/**
	 * @param standalone Set Apache XML Beans property
	 */
	public void setStandalone(boolean standalone) {
		isStandalone = standalone;
	}
	
	/**
	 * @return Source of this resolving information.
	 */
	public String getSourceName() {
		return sourceName;
	}
	
	/**
	 * @param newSourceName Set the information source.
	 */
	public void setSourceName(String newSourceName) {
		sourceName = newSourceName;
	}
	
	/**
	 * @return XML Scheme version.
	 */
	public String getVersion() {
		return version;
	}
	
	/**
	 * @param newVersion Set the XML Schema version.
	 */
	public void setVersion(String newVersion) {
		version = newVersion;
	}
	
	/**
	 * @return Returns the original user request.
	 */
	public String getRequest() {
		return request;
	}
	
	/**
	 * @param newRequest Set the user request.
	 */
	public void setRequest(String newRequest) {
		request = newRequest;
	}
	
	/**
	 * @return Status code of resolving.
	 */
	public short getStatusCode() {
		return statusCode;
	}
	
	/**
	 * @param newStatusCode Set the status code of this resolving operation.
	 */
	public void setStatusCode(short newStatusCode) {
		statusCode = newStatusCode;
	}
	
	/**
	 * @return The source of this information.
	 */
	public String getSource() {
		return source;
	}
	
	/**
	 * @param newSource Set the source of resolving information.
	 */
	public void setSource(String newSource) {
		source = newSource;
	}
	
	/**
	 * @return Return the organisation that generates this response.
	 */
	public String getOrganisation() {
		return organisation;
	}
	
	/**
	 * @param newOrganisation Set the responding organisation.
	 */
	public void setOrganisation(String newOrganisation) {
		organisation = newOrganisation;
	}	
	
	/**
	 * Generates a new PIDEF document and initializes with some basic fields.
	 * 
	 * @return Generated PIDEF document.
	 */
	public static PidefDocument generateNewPidefDocument(){
		//first define the desired options for XML document
		XmlOptions options = new XmlOptions();
		//options.setSaveAggressiveNamespaces();
		options.setCharacterEncoding(characterEncoding);
		//options.setBaseURI();
		options.setSaveNamespacesFirst();
		options.setValidateStrict();
		options.setSaveOuter();
		if(isPrettyPrint){
			options.setSavePrettyPrint();
		}
		
		//create a new, empty document and fill it with default values
		PidefDocument doc = PidefDocument.Factory.newInstance(options);
		Pidef root = doc.addNewPidef();
		if (root != null) {
			HeaderType header = root.addNewHeader();
			root.addNewData();

			java.util.Calendar cal = new java.util.GregorianCalendar();
			header.setTimestamp(cal);
			header.setRequest(request);
			//header.setStatusCode(statusCode);
			header.setSource(source);
			header.setOrganisation(organisation);
			//header.setPassword("");
		} else {
	        //TODO: eliminate IllegalArgumentException
			throw new IllegalArgumentException("ERROR during creating the PIDEF object. It should not be NULL!");
		}

		return doc;
	}
}
